@@ -34,69 +34,15 @@ the code, but the active DOM objects then need to be discarded.
 With the KHTMLAutomation KPart active, the following can be used at a normal
 Python prompt:
 
-  doc = qtxmldom.fromRemoteObject(obj)
+  doc = qtxmldom.fromRemoteNode(node)
 
-(Where obj has been obtained using the qtxmldom.remote module - see
+(Where node has been obtained using the qtxmldom.remote module - see
 examples/remote.py for more information.)
 """
 
 import xml.dom
 
-__version__ = "0.2.4"
-
-class RemoteNode(object):
-
-    "A representation of a remote object, accessed via DCOP."
-
-    def __init__(self, obj, accessor):
-        self.obj = obj
-        self.accessor = accessor
-
-    def __getattr__(self, name):
-        return RemoteMethod(self.obj, self.accessor, name)
-
-class RemoteMethod(object):
-
-    """
-    A wrapper around a remote method call, ensuring that the correct result is
-    obtained.
-    """
-
-    def __init__(self, obj, accessor, name):
-        import qt
-        self.qt = qt
-        self.obj = obj
-        self.accessor = accessor
-        self.name = name
-
-    def _convert_obj(self, obj):
-        if isinstance(obj, RemoteNode):
-            return obj.obj
-        else:
-            return obj
-
-    def __call__(self, *args):
-        method = getattr(self.accessor, self.name)
-
-        # Add the method's context and convert other arguments if appropriate.
-
-        args = (self.obj,) + tuple(map(self._convert_obj, args))
-
-        # Test the status.
-
-        status, result_list = method(*args)
-        if not status:
-            raise RuntimeError, "Remote method '%s' failed for node '%s'" % (self.name, self.obj)
-
-        if isinstance(result_list, self.qt.QStringList):
-            result_type = result_list[0]
-            result_value = result_list[1]
-            if result_type == "string":
-                return result_value
-            else:
-                return RemoteNode(result_value, self.accessor)
-        else:
-            return result_list
+__version__ = "0.2.5"
 
 class Implementation(object):
 
@@ -162,23 +108,21 @@ class khtmlImplementation(Implementation):
         if _node.nodeType() == xml.dom.Node.ELEMENT_NODE:
 
             # Promote underlying nodes to more capable HTML element objects.
+            # NOTE: No check is performed to verify this operation.
 
-            if self.get_string(_node.namespaceURI()) == xml.dom.XHTML_NAMESPACE:
-                localName = self.get_string(_node.localName()).lower()
-                if localName == "select":
-                    return self.khtml.DOM.HTMLSelectElement(_node)
-                elif localName == "option":
-                    return self.khtml.DOM.HTMLOptionElement(_node)
-                elif localName == "input":
-                    return self.khtml.DOM.HTMLInputElement(_node)
-                elif localName == "button":
-                    return self.khtml.DOM.HTMLButtonElement(_node)
-                elif localName == "form":
-                    return self.khtml.DOM.HTMLFormElement(_node)
-                elif localName == "textarea":
-                    return self.khtml.DOM.HTMLTextAreaElement(_node)
-                else:
-                    return self.khtml.DOM.Element(_node)
+            localName = self.get_string(_node.localName()).lower()
+            if localName == "select":
+                return self.khtml.DOM.HTMLSelectElement(_node)
+            elif localName == "option":
+                return self.khtml.DOM.HTMLOptionElement(_node)
+            elif localName == "input":
+                return self.khtml.DOM.HTMLInputElement(_node)
+            elif localName == "button":
+                return self.khtml.DOM.HTMLButtonElement(_node)
+            elif localName == "form":
+                return self.khtml.DOM.HTMLFormElement(_node)
+            elif localName == "textarea":
+                return self.khtml.DOM.HTMLTextAreaElement(_node)
             else:
                 return self.khtml.DOM.Element(_node)
 
@@ -839,39 +783,6 @@ class Node(object):
 
 # Convenience functions.
 
-def getRemoteDocument(remote_object):
-
-    """
-    Get a KHTML-style node for the given 'remote_object'. Use the
-    qtxmldom.remote module to find suitable objects to use with this function.
-    """
-
-    status, result = remote_object.getDocument()
-    if not status:
-        raise RuntimeError, "No remote document found for %s" % repr(remote_object)
-
-    try:
-        doc = result[1]
-        return getRemoteNode(doc, remote_object)
-    except IndexError:
-        raise RuntimeError, "No remote document found for %s" % repr(remote_object)
-
-def getRemoteNode(node, remote_object):
-
-    """
-    Get a KHTML-style node for the given 'node' accessed via the supplied
-    'remote_object'. Use the qtxmldom.remote module to find suitable objects to
-    use with this function.
-    """
-
-    return RemoteNode(node, remote_object)
-
-def fromRemoteObject(remote_object):
-
-    "Return a PyXML-style DOM for the given 'remote_object'."
-
-    return Node(getRemoteDocument(remote_object), khtmlRemoteImplementation())
-
 def fromRemoteNode(node):
 
     "Return a PyXML-style DOM for the given remote 'node'."
